@@ -37,6 +37,7 @@ use EBox::Gettext;
 use EBox::Config;
 #use EBox::LogAdmin qw ( :all );
 use EBox::Menu::Item;
+use EBox::Dashboard::ModuleStatus;
 use EBox::Exceptions::External;
 use EBox::Exceptions::Internal;
 use EBox::Exceptions::DataMissing;
@@ -112,7 +113,7 @@ sub _create
 	my $class = shift;
 	my $self = $class->SUPER::_create(name => 'ca',
 					  domain => 'ebox-ca',
-					  printableName => __('Certification Authority'),
+					  printableName => __n('Certification Authority'),
 #					  title => __n('Certification Authority'),
 					  @_);
 
@@ -1048,8 +1049,12 @@ sub generateCRL
 #       - path       - certificate path
 #       - serialNumber - serial number within CA
 #
+# Exceptions:
+#
+#       <EBox::Exceptions::External> - thrown if the CA is not created
+#
 sub listCertificates
-  {
+{
 
     my ($self, %args) = @_;
 
@@ -1061,6 +1066,12 @@ sub listCertificates
       throw EBox::Exceptions::Internal("State should be R, V or E");
     }
 
+    unless (-f INDEXFILE) {
+        throw EBox::Exceptions::External(
+            __('The Certification Authority Infrastructure is not available, create it first')
+           );
+    }
+
     my @lines = read_file( INDEXFILE );
     my @out = ();
 
@@ -1700,7 +1711,7 @@ sub menu
 
   my $folder = new EBox::Menu::Folder('name' => 'CA',
                     'text' => $self->printableName(),
-                    'separator' => __('Infrastructure'),
+                    'separator' => 'Infrastructure',
                     'order' => 440);
 
   $folder->add(new EBox::Menu::Item('url'  => 'CA/Index',
@@ -1782,6 +1793,33 @@ sub showModuleStatus
     return undef;
 }
 
+# Method: addModuleStatus
+#
+#       Overrides to show a custom status for CA module
+#
+# Overrides:
+#
+#       <EBox::Module::Service::addModuleStatus>
+#
+sub addModuleStatus
+{
+    my ($self, $section) = @_;
+
+    my $caStatus = __('Not created');
+    if ( $self->isAvailable() ) {
+        $caStatus = __('Available');
+    } elsif ( $self->isCreated() ) {
+        $caStatus = __('Created but not available');
+    }
+
+    $section->add(new EBox::Dashboard::ModuleStatus(
+        module        => $self->name(),
+        printableName => $self->printableName(),
+        nobutton      => 1,
+        statusStr     => $caStatus));
+
+}
+
 # Method: _supportActions
 #
 #   Overrides <EBox::Module::ServiceBase>
@@ -1797,7 +1835,9 @@ sub _supportActions
 # Group: Private methods
 
 # Method: _setConf # # Overrides: # # <EBox::Module::Service::_setConf> #
-sub _setConf { my ($self) = @_;
+sub _setConf {
+
+    my ($self) = @_;
 
     EBox::CA::Certificates->genCerts();
 }
@@ -2398,6 +2438,45 @@ sub _isLaterThanCA # (date)
 }
 
 
+# Method: report
+#
+# Returns:
+#    ref hash with the following fields:
+#    CAState: state of the CA certificate. It will be ono of this states:
+#       - R - Revoked
+#       - E - Expired
+#       - V - Valid
+#       - ! - Inexistent
+#
+#    nValidCertificates: number of valid active certificates
+#    nRevokedCertificates: number of revoked certificates
+#    nExpiredCertificates: number of expired certifcates
+#
+
+# Overrides: 
+#   <EBox::Module::Base::report>
+sub report
+{
+    my ($self) = @_;
+    my $currentCA = $self->currentCACertificateState();
+
+    my ($nValid, $nRevoked, $nExpired) = (0, 0, 0);
+    if ($currentCA ne '!') {
+        $nValid = @{ $self->listCertificates(state => 'V', excludeCA => 1) };
+        $nRevoked = @{ $self->listCertificates(state => 'R', excludeCA => 1) };
+        $nExpired = @{ $self->listCertificates(state => 'E', excludeCA => 1) };
+
+    }
+
+    return {
+            CAState => $currentCA,
+
+            nValidCertifcates     => $nValid,
+            nRevokedCertificates  => $nRevoked,
+            nExpiredCertificates  => $nExpired,
+           };
+}
+
 ## OpenSSL execution environment provided by OpenCA::OpenSSL
 ## through OpenCA application
 ## Modificated to adapt to OpenSSL environment
